[Rt-commit] r20102 - in rt/3.999/trunk: etc lib/RT/Model sbin share/html/Admin/Elements share/html/Admin/Global share/html/Admin/Global/StatusSchemas share/html/Admin/Queues

jesse at bestpractical.com jesse at bestpractical.com
Mon Jul 6 21:25:59 EDT 2009


Author: jesse
Date: Mon Jul  6 21:25:59 2009
New Revision: 20102

Modified:
   rt/3.999/trunk/etc/initialdata
   rt/3.999/trunk/lib/RT/Model/Queue.pm
   rt/3.999/trunk/lib/RT/Model/Ticket.pm
   rt/3.999/trunk/lib/RT/StatusSchema.pm
   rt/3.999/trunk/sbin/rt-migrate-db-from-3.8
   rt/3.999/trunk/share/html/Admin/Elements/SystemTabs
   rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Mappings.html
   rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Statuses.html
   rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Summary.html
   rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/index.html
   rt/3.999/trunk/share/html/Admin/Global/index.html
   rt/3.999/trunk/share/html/Admin/Queues/Modify.html

Log:
First round of renaming Status Schema to Workflow

Modified: rt/3.999/trunk/etc/initialdata
==============================================================================
--- rt/3.999/trunk/etc/initialdata	(original)
+++ rt/3.999/trunk/etc/initialdata	Mon Jul  6 21:25:59 2009
@@ -592,7 +592,7 @@
       },
     },
     { name => 'StatusSchemas',
-      description => 'all system status schemas',
+      description => 'all system workflows',
       content => {
         default => {
             initial  => ['new'],

Modified: rt/3.999/trunk/lib/RT/Model/Queue.pm
==============================================================================
--- rt/3.999/trunk/lib/RT/Model/Queue.pm	(original)
+++ rt/3.999/trunk/lib/RT/Model/Queue.pm	Mon Jul  6 21:25:59 2009
@@ -321,7 +321,7 @@
     my $res = RT::StatusSchema->load(
         (ref $self && $self->id) ? $self->__value('status_schema') : ''
     );
-    Jifty->log->error("Status schema doesn't exist") unless $res;
+    Jifty->log->error("Workflow doesn't exist") unless $res;
     return $res;
 }
 

Modified: rt/3.999/trunk/lib/RT/Model/Ticket.pm
==============================================================================
--- rt/3.999/trunk/lib/RT/StatusSchema.pm	(original)
+++ rt/3.999/trunk/lib/RT/StatusSchema.pm	Mon Jul  6 21:25:59 2009
@@ -32,11 +32,11 @@
 
 =head1 NAME
 
-RT::StatusSchema - class to access and manipulate status schemas
+RT::StatusSchema - class to access and manipulate workflows
 
 =head1 DESCRIPTION
 
-Status schema is a list statuses tickets can have, splitted into three groups:
+Workflow is a list statuses tickets can have, splitted into three groups:
 initial, active and inactive. As well it defines possible transitions between
 statuses, for example from 'stalled' status of default schema you can change
 status to 'open' only.
@@ -302,7 +302,7 @@
 
 =head3 create
 
-Creates a new status schema in the DB. Takes a param hash with
+Creates a new workflow in the DB. Takes a param hash with
 'name', 'initial', 'active', 'inactive' and 'transitions' keys.
 
 All arguments except 'name' are optional and can be filled later
@@ -339,7 +339,7 @@
     my ($status, $msg) = $self->_store_schemas( $name );
     return ($status, $msg) unless $status;
 
-    return (1, _('Created a new status schema'));
+    return (1, _('Created a new workflow'));
 }
 
 sub set_statuses {
@@ -351,7 +351,7 @@
         @_
     );
 
-    my $name = $self->name or return (0, _("Status schema is not loaded"));
+    my $name = $self->name or return (0, _("Workflow is not loaded"));
 
     my ($status, $msg) = $self->_set_statuses( %args, name => $name );
     return ($status, $msg) unless $status;
@@ -366,7 +366,7 @@
     my $self = shift;
     my %args = @_;
 
-    my $name = $self->name or return (0, _("Status schema is not loaded"));
+    my $name = $self->name or return (0, _("Workflow is not loaded"));
 
     my ($status, $msg) = $self->_set_transitions(
         transitions => \%args, name => $name
@@ -383,7 +383,7 @@
     my $self = shift;
     my %args = @_;
 
-    my $name = $self->name or return (0, _("Status schema is not loaded"));
+    my $name = $self->name or return (0, _("Workflow is not loaded"));
 
     my ($status, $msg) = $self->_set_actions(
         actions => \%args, name => $name
@@ -453,7 +453,7 @@
     my $name = shift;
     my ($status, $msg) = $RT::System->set_attribute(
         name => 'StatusSchemas',
-        description => 'all system status schemas',
+        description => 'all system workflows',
         content => \%STATUS_SCHEMAS,
     );
     $self->fill_cache;
@@ -530,10 +530,10 @@
     my %map = @_;
     $map{ lc $_ } = delete $map{ $_ } foreach keys %map;
 
-    return (0, _("Status schema is not loaded"))
+    return (0, _("Workflow is not loaded"))
         unless $self->name;
 
-    return (0, _("Status schema is not loaded"))
+    return (0, _("Workflow is not loaded"))
         unless $to->name;
 
 

Modified: rt/3.999/trunk/sbin/rt-migrate-db-from-3.8
==============================================================================
--- rt/3.999/trunk/sbin/rt-migrate-db-from-3.8	(original)
+++ rt/3.999/trunk/sbin/rt-migrate-db-from-3.8	Mon Jul  6 21:25:59 2009
@@ -97,7 +97,7 @@
 
 sub post_update_attributes_table {
 
-# need to add a row for the default status schema in Attributes and update
+# need to add a row for the default workflow in Attributes and update
 # part columns of that table
     require RT::Model::AttributeCollection;
     my $collection = RT::Model::AttributeCollection->new( current_user => RT->system_user );
@@ -135,7 +135,7 @@
     my @results = $attribute->create(
         name        => 'StatusSchemas',
         object      => RT->system,
-        description => 'all system status schemas',
+        description => 'all system workflows',
         content     => {
             default => {
                 initial     => ['new'],

Modified: rt/3.999/trunk/share/html/Admin/Elements/SystemTabs
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Elements/SystemTabs	(original)
+++ rt/3.999/trunk/share/html/Admin/Elements/SystemTabs	Mon Jul  6 21:25:59 2009
@@ -59,7 +59,7 @@
                B => { title => _('Templates'),
                         path => 'Admin/Global/Templates.html',
                       },
-                C => { title => _('Status Schemas'),
+                C => { title => _('Workflows'),
                         path => 'Admin/Global/StatusSchemas/index.html',
                         },
               

Modified: rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Mappings.html
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Mappings.html	(original)
+++ rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Mappings.html	Mon Jul  6 21:25:59 2009
@@ -10,7 +10,7 @@
 <&|/l&>Mapping between schemas is required when you want to move tickets between queues with different schemas.</&>
 
 % unless ( @list > 1 ) {
-<&|/l&>You need more than one status schema to be able to define mappings.</&>
+<&|/l&>You need more than one workflow to be able to define mappings.</&>
 % } else {
 <& Elements/MissingMaps &>
 
@@ -83,7 +83,7 @@
 </&>
 
 <%INIT>
-my $title = _("Modify mapping between status schemas");
+my $title = _("Modify mapping between workflows");
 
 use RT::StatusSchema;
 my @list = RT::StatusSchema->new->list;

Modified: rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Statuses.html
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Statuses.html	(original)
+++ rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Statuses.html	Mon Jul  6 21:25:59 2009
@@ -22,7 +22,7 @@
 </&>
 
 <%INIT>
-my $title = _("Modify system status schemas", $name);
+my $title = _("Modify system workflows", $name);
 
 use RT::StatusSchema;
 my $schema = RT::StatusSchema->new->load( $name );

Modified: rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Summary.html
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Summary.html	(original)
+++ rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/Summary.html	Mon Jul  6 21:25:59 2009
@@ -78,7 +78,7 @@
     );
 }
 my $qs_name = $m->comp( '/Elements/QueryString', name => $schema->name );
-my $title = _("'%1' status schema summary", $name);
+my $title = _("'%1' workflow summary", $name);
 
 
 my @all_maps = RT::StatusSchema->list;

Modified: rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/index.html
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/index.html	(original)
+++ rt/3.999/trunk/share/html/Admin/Global/StatusSchemas/index.html	Mon Jul  6 21:25:59 2009
@@ -20,15 +20,15 @@
 
 <form action="<% RT->config->get('web_path') %>/Admin/Global/StatusSchemas/index.html" method="post">
 
-Status schema name: <input name="name" value="" /><br />
+Workflow name: <input name="name" value="" /><br />
 
-<& /Elements/Submit, caption => _('Create a new status schema'), label => _('Create'), name => 'create' &>
+<& /Elements/Submit, caption => _('Create a new workflow'), label => _('Create'), name => 'create' &>
 </form>
 
 </&>
 
 <%INIT>
-my $title = _("Modify system status schemas");
+my $title = _("Modify system workflows");
 
 use RT::StatusSchema;
 my @list = RT::StatusSchema->new->list;

Modified: rt/3.999/trunk/share/html/Admin/Global/index.html
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Global/index.html	(original)
+++ rt/3.999/trunk/share/html/Admin/Global/index.html	Mon Jul  6 21:25:59 2009
@@ -64,8 +64,8 @@
         path  => '/Admin/Global/Templates.html',
     },
     C => {
-        title => _('Status Schemas'),
-        text  => _('Modify system status schemas'),
+        title => _('Workflows'),
+        text  => _('Modify system workflows'),
         path  => '/Admin/Global/StatusSchemas/index.html',
     },
     F => {

Modified: rt/3.999/trunk/share/html/Admin/Queues/Modify.html
==============================================================================
--- rt/3.999/trunk/share/html/Admin/Queues/Modify.html	(original)
+++ rt/3.999/trunk/share/html/Admin/Queues/Modify.html	Mon Jul  6 21:25:59 2009
@@ -67,7 +67,7 @@
 <td colspan="3"><input name="description" value="<% ($create) ? "" : $queue_obj->description %>" size="60" /></td>
 </tr>
 
-<tr><td align="right"><&|/l&>Status schema</&>:</td>
+<tr><td align="right"><&|/l&>Workflow</&>:</td>
 <td colspan="3"><& /Admin/Elements/SelectStatusSchema, default => $create? '' : $queue_obj->status_schema  &></td>
 </tr>
 


More information about the Rt-commit mailing list
--- rt/3.999/trunk/lib/RT/Model/Ticket.pm	(original)
+++ rt/3.999/trunk/lib/RT/Model/Ticket.pm	Mon Jul  6 21:25:59 2009
@@ -995,7 +995,7 @@
             return ( 0, _("There is no mapping for statuses between these queues. Contact your system administrator.") );
         }
         $new_status = $schema->map( $Newqueue_obj )->{ $self->status };
-        return ( 0, _("Mapping between queues' status schemas is incomplete. Contact your system administrator.") )
+        return ( 0, _("Mapping between queues' workflows is incomplete. Contact your system administrator.") )
             unless $new_status;
     }
 
@@ -2002,7 +2002,7 @@
 
 =cut
 
 # XXX, FIXME: disable this for a while, as it conflicts with status schemas
 #sub validate_status {
 #    my $self   = shift;
 #    my $status = shift;
@@ -2002,7 +2002,7 @@
 =cut
 
-# XXX, FIXME: disable this for a while, as it conflicts with status schemas
+# XXX, FIXME: disable this for a while, as it conflicts with workflows
 #sub validate_status {
 #    my $self   = shift;

Modified: rt/3.999/trunk/lib/RT/StatusSchema.pm
==============================================================================